# Generated by Django 2.0.4 on 2018-07-19 18:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('deeppages', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='page',
            name='changed_at',
            field=models.DateTimeField(auto_now=True, verbose_name='Changed At'),
        ),
        migrations.AlterField(
            model_name='page',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created At'),
        ),
    ]
