from django.test import TestCase
# from model_mommy import mommy


class PageTestCase(TestCase):
    def test_deep_page_settings(self):
        pass

    def test_create_deep_page(self):
        pass

    def test_create_duplicated_path_pages(self):
        pass

    def test_request_deep_page(self):
        pass
