# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-03-21 04:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='This name will be used to identify the page. Ex.: my page name', max_length=50, unique=True)),
                ('path', models.CharField(help_text='Type the absolute path. Ex.: /my-page-name/', max_length=100)),
                ('title', models.CharField(blank=True, default=None, max_length=100, null=True)),
                ('content', models.TextField(blank=True, default=None, null=True)),
                ('is_active', models.BooleanField(default=True)),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name=b'Created At')),
                ('changed_at', models.DateTimeField(auto_now=True, verbose_name=b'Changed At')),
            ],
            options={
                'ordering': ('name',),
                'get_latest_by': 'changed_at',
                'verbose_name': 'Page',
                'verbose_name_plural': 'Pages',
            },
        ),
    ]
